pub enum CancelType {
Show 20 variants
CancelByUser,
CancelByReduceOnly,
CancelByPrepareLiq,
CancelAllBeforeLiq,
CancelByPrepareAdl,
CancelAllBeforeAdl,
CancelByAdmin,
CancelBySettle,
CancelByTpSlTsClear,
CancelBySmp,
CancelByDCP,
CancelByRebalance,
CancelByCannotAffordOrderCost,
CancelByPmTrialMmOverEquity,
CancelByAccountBlocking,
CancelByDelivery,
CancelByMmpTriggered,
CancelByCrossSelfMuch,
CancelByCrossReachMaxTradeNum,
UNKNOWN,
}Variants
CancelByUser
CancelByReduceOnly
cancelled by reduceOnly
CancelByPrepareLiq
cancelled in order to attempt liquidation prevention by freeing up margin
CancelAllBeforeLiq
cancelled in order to attempt liquidation prevention by freeing up margin
CancelByPrepareAdl
cancelled due to ADL
CancelAllBeforeAdl
cancelled due to ADL
CancelByAdmin
CancelBySettle
cancelled due to delisting contract
CancelByTpSlTsClear
TP/SL order cancelled when the position is cleared
CancelBySmp
cancelled by SMP
CancelByDCP
cancelled by DCP triggering
CancelByRebalance
Spread trading: the order price of a single leg order is outside the limit price range.
CancelByCannotAffordOrderCost
CancelByPmTrialMmOverEquity
CancelByAccountBlocking
CancelByDelivery
CancelByMmpTriggered
CancelByCrossSelfMuch
CancelByCrossReachMaxTradeNum
UNKNOWN
Not documented