pub enum CopyTrading {
None,
Both,
UtaOnly,
NormalOnly,
}Variants
None
Regardless of normal account or UTA account, this trading pair does not support copy trading
Both
For both normal account and UTA account, this trading pair supports copy trading
UtaOnly
Only for UTA account,this trading pair supports copy trading
NormalOnly
Only for normal account, this trading pair supports copy trading