CreateType

Enum CreateType 

pub enum CreateType {
Show 26 variants CreateByUser, CreateByFutureSpread, CreateByAdminClosing, CreateBySettle, CreateByStopOrder, CreateByTakeProfit, CreateByPartialTakeProfit, CreateByStopLoss, CreateByPartialStopLoss, CreateByTrailingStop, CreateByLiq, CreateByTakeOverPassThrough, CreateByAdlPassThrough, CreateByBlockPassThrough, CreateByBlockTradeMovePositionPassThrough, CreateByClosing, CreateByFGridBot, CloseByFGridBot, CreateByTWAP, CreateByTVSignal, CreateByMmRateClose, CreateByMartingaleBot, CloseByMartingaleBot, CreateByIceBerg, CreateByArbitrage, CreateByDdh,
}

Variants



CreateByUser



CreateByFutureSpread

Spread order



CreateByAdminClosing



CreateBySettle

USDC Futures delivery; position closed as a result of the delisting of a contract. This is recorded as a trade but not an order.



CreateByStopOrder

Futures conditional order



CreateByTakeProfit

Futures take profit order



CreateByPartialTakeProfit

Futures partial take profit order



CreateByStopLoss

Futures stop loss order



CreateByPartialStopLoss

Futures partial stop loss order



CreateByTrailingStop

Futures trailing stop order



CreateByLiq

Laddered liquidation to reduce the required maintenance margin



CreateByTakeOverPassThrough

If the position is still subject to liquidation (i.e., does not meet the required maintenance margin level), the position shall be taken over by the liquidation engine and closed at the bankruptcy price.



CreateByAdlPassThrough

Auto-Deleveraging(ADL)



CreateByBlockPassThrough

Order placed via Paradigm



CreateByBlockTradeMovePositionPassThrough

Order created by move position



CreateByClosing

The close order placed via web or app position area - web/app



CreateByFGridBot

Order created via grid bot - web/app



CloseByFGridBot

Order closed via grid bot - web/app



CreateByTWAP

Order created by TWAP - web/app



CreateByTVSignal

Order created by TV webhook - web/app



CreateByMmRateClose

Order created by Mm rate close function - web/app



CreateByMartingaleBot

Order created by Martingale bot - web/app



CloseByMartingaleBot

Order closed by Martingale bot - web/app



CreateByIceBerg

Order created by Ice berg strategy - web/app



CreateByArbitrage

Order created by arbitrage - web/app



CreateByDdh

Option dynamic delta hedge order - web/app