pub enum MarginTrading {
None,
Both,
UtaOnly,
NormalSpotOnly,
}Variants
None
Regardless of normal account or UTA account, this trading pair does not support margin trading
Both
For both normal account and UTA account, this trading pair supports margin trading
UtaOnly
Only for UTA account,this trading pair supports margin trading
NormalSpotOnly
Only for normal account, this trading pair supports margin trading