pub enum TickDirection {
PlusTick,
ZeroPlusTick,
MinusTick,
ZeroMinusTick,
}Variants
PlusTick
price rise
ZeroPlusTick
trade occurs at the same price as the previous trade, which occurred at a price higher than that for the trade preceding it
MinusTick
price drop
ZeroMinusTick
trade occurs at the same price as the previous trade, which occurred at a price lower than that for the trade preceding it