Struct bybit::errors::BybitContentError
source · pub struct BybitContentError {
pub code: i16,
pub msg: String,
}Expand description
BybitContentError is a struct that represents the error returned by the Bybit API. It has two fields: code, which is an i16 representing the error code, and msg, which is a String representing the error message.
Fields
code: i16msg: StringTrait Implementations
sourceimpl Debug for BybitContentError
impl Debug for BybitContentError
sourceimpl<'de> Deserialize<'de> for BybitContentError
impl<'de> Deserialize<'de> for BybitContentError
sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more