APIKeyInformation

Struct APIKeyInformation 

pub struct APIKeyInformation {
Show 22 fields pub id: String, pub note: String, pub api_key: String, pub read_only: i64, pub secret: String, pub permissions: APIKeyPermissions, pub ips: Vec<String>, pub key_type: i64, pub deadline_day: u64, pub expired_at: String, pub created_at: String, pub uta: i64, pub user_id: i64, pub inviter_id: i64, pub vip_level: VipLevel, pub mkt_maker_level: String, pub affiliate_id: i64, pub rsa_public_key: String, pub is_master: bool, pub parent_uid: String, pub kyc_level: String, pub kyc_region: String,
}

Fields

id: String

Unique ID. Internal use

note: String

The remark

api_key: String

Api key

read_only: i64

0:Read and Write. 1:Read only

secret: String

Always “”

permissions: APIKeyPermissions

The types of permission

ips: Vec<String>

IP bound

key_type: i64

The type of api key. 1:personal, 2:connected to the third-party app

deadline_day: u64

The remaining valid days of api key. Only for those api key with no IP bound or the password has been changed

expired_at: String

The expiry day of the api key. Only for those api key with no IP bound or the password has been changed

created_at: String

The create day of the api key

uta: i64

Whether the account to which the account upgrade to unified trade account. 0:regular account; 1:unified trade account

user_id: i64

User ID

inviter_id: i64

Inviter ID (the UID of the account which invited this account to the platform)

vip_level: VipLevel

VIP Level

mkt_maker_level: String

Market maker level

affiliate_id: i64

Affiliate Id. 0 represents that there is no binding relationship.

rsa_public_key: String

Rsa public key

is_master: bool

If this api key belongs to master account or not

parent_uid: String

The main account uid. Returns “0” when the endpoint is called by main account

kyc_level: String

Personal account kyc level. LEVEL_DEFAULT, LEVEL_1, LEVEL_2

kyc_region: String

Personal account kyc region