pub struct GetOpenClosedOrdersParams {
pub category: Category,
pub symbol: Option<String>,
pub base_coin: Option<String>,
pub settle_coin: Option<String>,
pub order_id: Option<String>,
pub order_link_id: Option<String>,
pub open_only: Option<i32>,
pub order_filter: Option<OrderFilter>,
pub limit: Option<i32>,
pub cursor: Option<String>,
}Fields
category: CategoryProduct type UTA2.0, UTA1.0: linear, inverse, spot, option classic account: linear, inverse, spot
symbol: Option<String>Symbol name, like BTCUSDT, uppercase only. For linear, either symbol, baseCoin, settleCoin is required
base_coin: Option<String>Base coin, uppercase only Supports linear, inverse & option option: it returns all option open orders by default
settle_coin: Option<String>Settle coin, uppercase only linear: either symbol, baseCoin or settleCoin is required spot: not supported option: USDT or USDC
order_id: Option<String>Order ID
order_link_id: Option<String>User customized order ID
open_only: Option<i32>0(default): UTA2.0, UTA1.0, classic account query open status orders (e.g., New, PartiallyFilled) only 1: UTA2.0, UTA1.0(except inverse) 2: UTA1.0(inverse), classic account Query a maximum of recent 500 closed status records are kept under each account each category (e.g., Cancelled, Rejected, Filled orders). If the Bybit service is restarted due to an update, this part of the data will be cleared and accumulated again, but the order records will still be queried in order history openOnly param will be ignored when query by orderId or orderLinkId Classic spot: not supported
order_filter: Option<OrderFilter>Order: active order, StopOrder: conditional order for Futures and Spot, tpslOrder: spot TP/SL order, OcoOrder: Spot oco order, BidirectionalTpslOrder: Spot bidirectional TPSL order
- classic account spot: return Order active order by default
- Others: all kinds of orders by default
limit: Option<i32>Limit for data size per page. [1, 50]. Default: 20
cursor: Option<String>Cursor. Use the nextPageCursor token from the response to retrieve the next page of the result set
Implementations
Sourceimpl GetOpenClosedOrdersParams
impl GetOpenClosedOrdersParams
pub fn new(category: Category) -> Self
pub fn with_symbol(self, v: String) -> Self
pub fn with_base_coin(self, v: String) -> Self
pub fn with_settle_coin(self, v: String) -> Self
pub fn with_order_id(self, v: String) -> Self
pub fn with_order_link_id(self, v: String) -> Self
pub fn with_open_only(self, v: i32) -> Self
pub fn with_order_filter(self, v: OrderFilter) -> Self
pub fn with_limit(self, v: i32) -> Self
pub fn with_cursor(self, v: String) -> Self