pub struct GetPositionInfoParams {
pub category: Category,
pub symbol: Option<String>,
pub base_coin: Option<String>,
pub settle_coin: Option<String>,
pub limit: Option<u64>,
pub cursor: Option<String>,
}Fields
category: CategoryProduct type UTA2.0, UTA1.0: linear, inverse, option Classic account: linear, inverse
symbol: Option<String>Symbol name, like BTCUSDT, uppercase only If symbol passed, it returns data regardless of having position or not. If symbol=null and settleCoin specified, it returns position size greater than zero.
base_coin: Option<String>Base coin, uppercase only. option only. Return all option positions if not passed
settle_coin: Option<String>Settle coin linear: either symbol or settleCoin is required. symbol has a higher priority
limit: Option<u64>Limit for data size per page. [1, 200]. Default: 20
cursor: Option<String>Cursor. Use the nextPageCursor token from the response to retrieve the next page of the result set
Implementations
Sourceimpl GetPositionInfoParams
impl GetPositionInfoParams
pub fn new(category: Category) -> Self
pub fn with_symbol(self, v: String) -> Self
pub fn with_base_coin(self, v: String) -> Self
pub fn with_settle_coin(self, v: String) -> Self
pub fn with_limit(self, v: u64) -> Self
pub fn with_cursor(self, v: String) -> Self