pub struct GetTransactionLogParams {
pub account_type: Option<AccountType>,
pub category: Option<Category>,
pub currency: Option<String>,
pub base_coin: Option<String>,
pub settle_coin: Option<String>,
pub log_type: Option<String>,
pub trans_sub_type: Option<String>,
pub start_time: Option<Timestamp>,
pub end_time: Option<Timestamp>,
pub limit: Option<u64>,
pub cursor: Option<String>,
}Fields
account_type: Option<AccountType>Account Type. UNIFIED
category: Option<Category>Product type spot,linear,option,inverse
currency: Option<String>Currency, uppercase only
base_coin: Option<String>BaseCoin, uppercase only. e.g., BTC of BTCPERP
settle_coin: Option<String>Not documented. Settle coin linear: either symbol or settleCoin is required. symbol has a higher priority
log_type: Option<String>Types of transaction logs
trans_sub_type: Option<String>movePosition, used to filter trans logs of Move Position only
start_time: Option<Timestamp>The start timestamp (ms) startTime and endTime are not passed, return 24 hours by default Only startTime is passed, return range between startTime and startTime+24 hours Only endTime is passed, return range between endTime-24 hours and endTime If both are passed, the rule is endTime - startTime <= 7 days
end_time: Option<Timestamp>The end timestamp (ms)
limit: Option<u64>Limit for data size per page. [1, 50]. Default: 20
cursor: Option<String>Cursor. Use the nextPageCursor token from the response to retrieve the next page of the result set
Implementations
Sourceimpl GetTransactionLogParams
impl GetTransactionLogParams
pub fn new() -> Self
pub fn with_account_type(self, v: AccountType) -> Self
pub fn with_category(self, v: Category) -> Self
pub fn with_currency(self, v: String) -> Self
pub fn with_base_coin(self, v: String) -> Self
pub fn with_settle_coin(self, v: String) -> Self
pub fn with_log_type(self, v: String) -> Self
pub fn with_trans_sub_type(self, v: String) -> Self
pub fn with_start_time(self, v: Timestamp) -> Self
pub fn with_end_time(self, v: Timestamp) -> Self
pub fn with_limit(self, v: u64) -> Self
pub fn with_cursor(self, v: String) -> Self