pub struct GetWalletBalanceParams {
pub account_type: AccountType,
pub coin: Option<String>,
}Fields
account_type: AccountTypeAccount type UTA2.0: UNIFIED UTA1.0: UNIFIED, CONTRACT(inverse derivatives wallet) Classic account: CONTRACT, SPOT To get Funding wallet balance, please go to this endpoint
coin: Option<String>Coin name, uppercase only If not passed, it returns non-zero asset info You can pass multiple coins to query, separated by comma. USDT,USDC