pub struct SpotInstrumentsInfo {
pub symbol: String,
pub base_coin: String,
pub quote_coin: String,
pub innovation: bool,
pub status: Status,
pub margin_trading: String,
pub st_tag: bool,
pub lot_size_filter: SpotLotSizeFilter,
pub price_filter: SpotPriceFilter,
pub risk_parameters: RiskParameters,
}Fields
symbol: StringSymbol name
base_coin: StringBase coin
quote_coin: StringQuote coin
innovation: boolWhether or not this is an innovation zone token. 0: false, 1: true
status: StatusInstrument status
margin_trading: StringMargin trade symbol or not This is to identify if the symbol support margin trading under different account modes You may find some symbols not supporting margin buy or margin sell, so you need to go to Collateral Info (UTA) to check if that coin is borrowable
st_tag: boolWhether or not it has an special treatment label. 0: false, 1: true
lot_size_filter: SpotLotSizeFilterSize attributes
price_filter: SpotPriceFilterPrice attributes
risk_parameters: RiskParametersRisk parameters for limit order price, refer to announcement