TransactionLog

Struct TransactionLog 

pub struct TransactionLog {
Show 22 fields pub id: String, pub symbol: String, pub category: Category, pub side: Side, pub transaction_time: Timestamp, pub log_type: String, pub trans_sub_type: String, pub qty: Decimal, pub size: Decimal, pub currency: String, pub trade_price: Decimal, pub funding: Decimal, pub fee: Decimal, pub cash_flow: Decimal, pub change: Decimal, pub cash_balance: Decimal, pub fee_rate: Decimal, pub bonus_change: Decimal, pub trade_id: String, pub order_id: String, pub order_link_id: Option<String>, pub extra_fees: Option<Value>,
}

Fields

id: String

Unique id

symbol: String

Symbol name

category: Category

Product type

side: Side

Side. Buy,Sell,None

transaction_time: Timestamp

Transaction timestamp (ms)

log_type: String

Type

trans_sub_type: String

Transaction sub type, movePosition, used for the logs generated by move position. “” by default

qty: Decimal

Quantity Spot: the negative means the qty of this currency is decreased, the positive means the qty of this currency is increased Perps & Futures: it is the quantity for each trade entry and it does not have direction

size: Decimal

Size. The rest position size after the trade is executed, and it has direction, i.e., short with “-”

currency: String

e.g., USDC, USDT, BTC, ETH

trade_price: Decimal

Trade price

funding: Decimal

Funding fee Positive fee value means receive funding; negative fee value means pay funding. This is opposite to the execFee from Get Trade History. For USDC Perp, as funding settlement and session settlement occur at the same time, they are represented in a single record at settlement. Please refer to funding to understand funding fee, and cashFlow to understand 8-hour P&L.

fee: Decimal

Trading fee Positive fee value means expense Negative fee value means rebates

cash_flow: Decimal

Cash flow, e.g., (1) close the position, and unRPL converts to RPL, (2) 8-hour session settlement for USDC Perp and Futures, (3) transfer in or transfer out. This does not include trading fee, funding fee

change: Decimal

Change = cashFlow + funding - fee

cash_balance: Decimal

Cash balance. This is the wallet balance after a cash change

fee_rate: Decimal

When type=TRADE, then it is trading fee rate When type=SETTLEMENT, it means funding fee rate. For side=Buy, feeRate=market fee rate; For side=Sell, feeRate= - market fee rate

bonus_change: Decimal

The change of bonus

trade_id: String

Trade ID

order_id: String

Order ID

order_link_id: Option<String>

User customised order ID

extra_fees: Option<Value>

Trading fee rate information. Currently, this data is returned only for spot orders placed on the Indonesian site or spot fiat currency orders placed on the EU site. In other cases, an empty string is returned. Enum: feeType, subFeeType