WalletBalance

Struct WalletBalance 

pub struct WalletBalance {
Show 15 fields pub account_type: AccountType, pub account_im_rate: Decimal, pub account_im_rate_by_mp: Decimal, pub account_mm_rate: Decimal, pub account_mm_rate_by_mp: Decimal, pub total_equity: Decimal, pub total_wallet_balance: Decimal, pub total_margin_balance: Decimal, pub total_available_balance: Decimal, pub total_perp_upl: Decimal, pub total_initial_margin: Decimal, pub total_initial_margin_by_mp: Decimal, pub total_maintenance_margin: Decimal, pub total_maintenance_margin_by_mp: Decimal, pub coin: HashMap<String, WalletCoin>,
}

Fields

account_type: AccountType

Account type

account_im_rate: Decimal

Account IM rate You can refer to this Glossary to understand the below fields calculation and meaning All account wide fields are not applicable to UTA2.0(isolated margin), UTA1.0(isolated margin), UTA1.0(CONTRACT), classic account(SPOT, CONTRACT)

account_im_rate_by_mp: Decimal

Account initial margin (USD) calculated by mark price: ∑Asset Total Initial Margin Base Coin calculated by mark price

account_mm_rate: Decimal

Account MM rate

account_mm_rate_by_mp: Decimal

Account maintenance margin (USD) calculated by mark price: ∑ Asset Total Maintenance Margin Base Coin calculated by mark price

total_equity: Decimal

Account total equity (USD)

total_wallet_balance: Decimal

Account wallet balance (USD): ∑Asset Wallet Balance By USD value of each asset

total_margin_balance: Decimal

Account margin balance (USD): totalWalletBalance + totalPerpUPL

total_available_balance: Decimal

Account available balance (USD), Cross Margin: totalMarginBalance - totalInitialMargin

total_perp_upl: Decimal

Account Perps and Futures unrealised p&l (USD): ∑Each Perp and USDC Futures upl by base coin

total_initial_margin: Decimal

Account initial margin (USD): ∑Asset Total Initial Margin Base Coin

total_initial_margin_by_mp: Decimal

Account initial margin (USD) calculated by mark price: ∑Asset Total Initial Margin Base Coin calculated by mark price

total_maintenance_margin: Decimal

Account maintenance margin (USD): ∑ Asset Total Maintenance Margin Base Coin

total_maintenance_margin_by_mp: Decimal

Account maintenance margin (USD) calculated by mark price: ∑ Asset Total Maintenance Margin Base Coin calculated by mark price

coin: HashMap<String, WalletCoin>

Implementations

Source

impl WalletBalance

pub fn update(&mut self, msg: WalletMsg)