CryptoLoanCode

Enum CryptoLoanCode 

#[repr(i32)]
pub enum CryptoLoanCode { CryptoLoanNotSupported = 150_001, InsufficientBalance = 150_002, InvalidLoanAmount = 150_003, LoanFailed = 150_004, RepayFailed = 150_005, InvalidRepayAmount = 150_006, CryptoLoanDisabled = 150_007, LoanOrderNotExist = 150_008, }
Enum representing Bybit API V5 Crypto Loan return error/codes.

See: https://bybit-exchange.github.io/docs/v5/error#crypto-loan

Variants



CryptoLoanNotSupported = 150_001

Crypto loan is not supported.



InsufficientBalance = 150_002

Insufficient balance in account.



InvalidLoanAmount = 150_003

Invalid loan amount.



LoanFailed = 150_004

Loan failed.



RepayFailed = 150_005

Repay failed.



InvalidRepayAmount = 150_006

Invalid repay amount.



CryptoLoanDisabled = 150_007

Crypto loan is disabled for this account.



LoanOrderNotExist = 150_008

Crypto loan order does not exist.

Implementations

Source

impl CryptoLoanCode

pub fn from_code<T>(code: T) -> Option<Self>
where T: Into<i32> + Copy,

Converts an error code (as i32 or &str) to a CryptoLoanError variant. Returns None if the code doesn’t match any variant or if the string cannot be parsed.

pub fn message(&self) -> &'static str

Returns the error message associated with the error code.