GeneralCode

Enum GeneralCode 

#[repr(i32)]
pub enum GeneralCode {
Show 30 variants InvalidParameters = 10_001, InvalidRequest = 10_002, InvalidApiKey = 10_003, SignatureError = 10_004, PermissionDenied = 10_005, TooManyVisits = 10_006, UnmatchedIp = 10_010, InvalidAgentHeader = 10_014, TimestampError = 10_017, SymbolNotExist = 10_021, SymbolNotTrading = 10_022, InvalidJsonFormat = 100_400, InvalidCategory = 100_401, InternalServerError = 100_500, InvalidAccountType = 100_600, InsufficientBalance = 100_601, InvalidSubAccountName = 100_602, SubAccountNotExist = 100_603, MasterAccountNotExist = 100_604, SubAccountCreationFailed = 100_605, SubAccountAlreadyExists = 100_606, InvalidApiKeyPermission = 100_607, ApiKeyUpdateFailed = 100_608, ApiKeyDisabled = 100_609, ApiKeyDeletionFailed = 100_610, InvalidBatchOrder = 100_611, SubAccountFrozen = 100_612, SubAccountPermissionError = 100_613, MasterAccountFrozen = 100_614, MasterSubRelationshipExists = 100_615,
}
Enum representing Bybit API V5 General return error/codes.

See: https://bybit-exchange.github.io/docs/v5/error#general-error-codes

Variants



InvalidParameters = 10_001

Invalid parameter(s).



InvalidRequest = 10_002

Invalid request: server error or request timeout.



InvalidApiKey = 10_003

API key is invalid.



SignatureError = 10_004

Signature error.



PermissionDenied = 10_005

Permission denied.



TooManyVisits = 10_006

Too many visits, exceeding IP limit.



UnmatchedIp = 10_010

Unmatched IP: API key not bound to this IP.



InvalidAgentHeader = 10_014

Request header bybit-agent is empty or invalid.



TimestampError = 10_017

Timestamp is expired or there is a clock skew.



SymbolNotExist = 10_021

Futures/Options symbol does not exist.



SymbolNotTrading = 10_022

Symbol is not trading.



InvalidJsonFormat = 100_400

Invalid JSON format.



InvalidCategory = 100_401

Invalid category.



InternalServerError = 100_500

Internal server error.



InvalidAccountType = 100_600

Invalid account type.



InsufficientBalance = 100_601

Insufficient balance in account.



InvalidSubAccountName = 100_602

Invalid sub-account name.



SubAccountNotExist = 100_603

Sub-account does not exist.



MasterAccountNotExist = 100_604

Master account does not exist.



SubAccountCreationFailed = 100_605

Failed to create sub-account.



SubAccountAlreadyExists = 100_606

Sub-account already exists.



InvalidApiKeyPermission = 100_607

Invalid API key permission.



ApiKeyUpdateFailed = 100_608

Failed to update API key.



ApiKeyDisabled = 100_609

API key is disabled.



ApiKeyDeletionFailed = 100_610

Failed to delete API key.



InvalidBatchOrder = 100_611

Invalid batch order request: too many orders or other issues.



SubAccountFrozen = 100_612

Sub-account is frozen.



SubAccountPermissionError = 100_613

Sub-account permission error.



MasterAccountFrozen = 100_614

Master account is frozen.



MasterSubRelationshipExists = 100_615

Master-sub relationship already exists.

Implementations

Source

impl GeneralCode

pub fn from_code<T>(code: T) -> Option<Self>
where T: Into<i32> + Copy,

Converts an error code (as i32) to a GeneralError variant. Returns None if the code doesn’t match any variant.

pub fn message(&self) -> &'static str

Returns the error message associated with the error code.