pub enum LinearTickerData {
Snapshot(LinearTickerDataSnapshot),
Delta(LinearTickerDataDelta),
}Variants
Snapshot(LinearTickerDataSnapshot)
Delta(LinearTickerDataDelta)
Implementations
Sourceimpl LinearTickerData
impl LinearTickerData
Sourcepub fn try_unwrap_snapshot(
self,
) -> Result<LinearTickerDataSnapshot, TryUnwrapError<Self>>
pub fn try_unwrap_snapshot( self, ) -> Result<LinearTickerDataSnapshot, TryUnwrapError<Self>>
Attempts to unwrap this value to the LinearTickerData::Snapshot variant.
Returns a [TryUnwrapError] with the original value if this value is of any other type.
Sourcepub fn try_unwrap_delta(
self,
) -> Result<LinearTickerDataDelta, TryUnwrapError<Self>>
pub fn try_unwrap_delta( self, ) -> Result<LinearTickerDataDelta, TryUnwrapError<Self>>
Attempts to unwrap this value to the LinearTickerData::Delta variant.
Returns a [TryUnwrapError] with the original value if this value is of any other type.