pub struct DepositAddressChainInfo {
pub chain_type: String,
pub address_deposit: String,
pub tag_deposit: String,
pub chain: String,
pub batch_release_limit: String,
pub contract_address: String,
}Expand description
Deposit address chain information
Fields
chain_type: StringChain type
address_deposit: StringThe address for deposit
tag_deposit: StringTag of deposit
chain: StringChain
batch_release_limit: StringThe deposit limit for this coin in this chain. "-1" means no limit
contract_address: StringThe contract address of the coin. Only display last 6 characters, if there is no contract address, it shows ""