pub struct OptionsTicker {Show 25 fields
pub symbol: String,
pub bid1_price: String,
pub bid1_size: String,
pub bid1_iv: String,
pub ask1_price: String,
pub ask1_size: String,
pub ask1_iv: String,
pub last_price: String,
pub high_price_24h: String,
pub low_price_24h: String,
pub mark_price: String,
pub index_price: String,
pub mark_iv: String,
pub underlying_price: String,
pub open_interest: String,
pub turnover_24h: String,
pub volume_24h: String,
pub total_volume: String,
pub total_turnover: String,
pub delta: String,
pub gamma: String,
pub vega: String,
pub theta: String,
pub predicted_delivery_price: String,
pub change_24h: String,
}Expand description
Ticker data for options contracts.
Contains market data for options contracts, including Greeks (delta, gamma, vega, theta), implied volatility, and other options-specific metrics.
Fields
symbol: StringSymbol name.
bid1_price: StringBest bid price.
bid1_size: StringBest bid size.
bid1_iv: StringBest bid implied volatility.
ask1_price: StringBest ask price.
ask1_size: StringBest ask size.
ask1_iv: StringBest ask implied volatility.
last_price: StringLast traded price.
high_price_24h: StringThe highest price in the last 24 hours.
low_price_24h: StringThe lowest price in the last 24 hours.
mark_price: StringMark price.
index_price: StringIndex price.
mark_iv: StringMark price implied volatility.
underlying_price: StringUnderlying asset price.
open_interest: StringOpen interest size.
turnover_24h: StringTurnover for 24h.
volume_24h: StringVolume for 24h.
total_volume: StringTotal volume.
total_turnover: StringTotal turnover.
delta: StringDelta - rate of change of option price with respect to underlying price.
gamma: StringGamma - rate of change of delta with respect to underlying price.
vega: StringVega - rate of change of option price with respect to implied volatility.
theta: StringTheta - rate of change of option price with respect to time.
predicted_delivery_price: StringPredicted delivery price. It has a value 30 mins before delivery.
change_24h: StringThe change in the last 24 hours.
Implementations
Sourceimpl OptionsTicker
impl OptionsTicker
Sourcepub fn bid1_price_f64(&self) -> Option<f64>
pub fn bid1_price_f64(&self) -> Option<f64>
Returns the best bid price as a floating-point number, if parseable.
Sourcepub fn ask1_price_f64(&self) -> Option<f64>
pub fn ask1_price_f64(&self) -> Option<f64>
Returns the best ask price as a floating-point number, if parseable.
Sourcepub fn last_price_f64(&self) -> Option<f64>
pub fn last_price_f64(&self) -> Option<f64>
Returns the last price as a floating-point number, if parseable.
Sourcepub fn mark_price_f64(&self) -> Option<f64>
pub fn mark_price_f64(&self) -> Option<f64>
Returns the mark price as a floating-point number, if parseable.
Sourcepub fn index_price_f64(&self) -> Option<f64>
pub fn index_price_f64(&self) -> Option<f64>
Returns the index price as a floating-point number, if parseable.
Sourcepub fn underlying_price_f64(&self) -> Option<f64>
pub fn underlying_price_f64(&self) -> Option<f64>
Returns the underlying price as a floating-point number, if parseable.
Sourcepub fn change_24h_f64(&self) -> Option<f64>
pub fn change_24h_f64(&self) -> Option<f64>
Returns the 24-hour change as a floating-point number, if parseable.
Sourcepub fn high_price_24h_f64(&self) -> Option<f64>
pub fn high_price_24h_f64(&self) -> Option<f64>
Returns the 24-hour high price as a floating-point number, if parseable.
Sourcepub fn low_price_24h_f64(&self) -> Option<f64>
pub fn low_price_24h_f64(&self) -> Option<f64>
Returns the 24-hour low price as a floating-point number, if parseable.
Sourcepub fn open_interest_f64(&self) -> Option<f64>
pub fn open_interest_f64(&self) -> Option<f64>
Returns the open interest as a floating-point number, if parseable.
Sourcepub fn volume_24h_f64(&self) -> Option<f64>
pub fn volume_24h_f64(&self) -> Option<f64>
Returns the 24-hour volume as a floating-point number, if parseable.
Sourcepub fn turnover_24h_f64(&self) -> Option<f64>
pub fn turnover_24h_f64(&self) -> Option<f64>
Returns the 24-hour turnover as a floating-point number, if parseable.
Sourcepub fn total_volume_f64(&self) -> Option<f64>
pub fn total_volume_f64(&self) -> Option<f64>
Returns the total volume as a floating-point number, if parseable.
Sourcepub fn total_turnover_f64(&self) -> Option<f64>
pub fn total_turnover_f64(&self) -> Option<f64>
Returns the total turnover as a floating-point number, if parseable.
Sourcepub fn delta_f64(&self) -> Option<f64>
pub fn delta_f64(&self) -> Option<f64>
Returns the delta as a floating-point number, if parseable.
Sourcepub fn gamma_f64(&self) -> Option<f64>
pub fn gamma_f64(&self) -> Option<f64>
Returns the gamma as a floating-point number, if parseable.
Sourcepub fn vega_f64(&self) -> Option<f64>
pub fn vega_f64(&self) -> Option<f64>
Returns the vega as a floating-point number, if parseable.
Sourcepub fn theta_f64(&self) -> Option<f64>
pub fn theta_f64(&self) -> Option<f64>
Returns the theta as a floating-point number, if parseable.
Sourcepub fn bid1_iv_f64(&self) -> Option<f64>
pub fn bid1_iv_f64(&self) -> Option<f64>
Returns the bid implied volatility as a floating-point number, if parseable.
Sourcepub fn ask1_iv_f64(&self) -> Option<f64>
pub fn ask1_iv_f64(&self) -> Option<f64>
Returns the ask implied volatility as a floating-point number, if parseable.
Sourcepub fn mark_iv_f64(&self) -> Option<f64>
pub fn mark_iv_f64(&self) -> Option<f64>
Returns the mark implied volatility as a floating-point number, if parseable.
Sourcepub fn predicted_delivery_price_f64(&self) -> Option<f64>
pub fn predicted_delivery_price_f64(&self) -> Option<f64>
Returns the predicted delivery price as a floating-point number, if parseable.
Sourcepub fn bid1_size_f64(&self) -> Option<f64>
pub fn bid1_size_f64(&self) -> Option<f64>
Returns the bid size as a floating-point number, if parseable.
Sourcepub fn ask1_size_f64(&self) -> Option<f64>
pub fn ask1_size_f64(&self) -> Option<f64>
Returns the ask size as a floating-point number, if parseable.
Sourcepub fn bid_ask_size_ratio(&self) -> Option<f64>
pub fn bid_ask_size_ratio(&self) -> Option<f64>
Returns the bid-ask size ratio.
Sourcepub fn total_size(&self) -> Option<f64>
pub fn total_size(&self) -> Option<f64>
Returns the total size (bid + ask).