pub struct SingleCoinBalanceRequest<'a> {
pub member_id: Option<&'a str>,
pub to_member_id: Option<&'a str>,
pub account_type: &'a str,
pub to_account_type: Option<&'a str>,
pub coin: &'a str,
pub with_bonus: Option<u8>,
pub with_transfer_safe_amount: Option<u8>,
pub with_ltv_transfer_safe_amount: Option<u8>,
}Expand description
Request for getting single coin balance
Fields
member_id: Option<&'a str>UID. Required when querying sub UID balance with master api key
to_member_id: Option<&'a str>UID. Required when querying the transferable balance between different UIDs
account_type: &'a strAccount type
to_account_type: Option<&'a str>To account type. Required when querying the transferable balance between different account types
coin: &'a strCoin, uppercase only
with_bonus: Option<u8>0(default): not query bonus. 1: query bonus
with_transfer_safe_amount: Option<u8>Whether query delay withdraw/transfer safe amount 0(default): false, 1: true
with_ltv_transfer_safe_amount: Option<u8>For OTC loan users in particular, you can check the transferable amount under risk level 0(default): false, 1: true toAccountType is mandatory