pub struct SubDepositRecordRequest<'a> {
pub id: Option<&'a str>,
pub tx_id: Option<&'a str>,
pub sub_member_id: &'a str,
pub coin: Option<&'a str>,
pub start_time: Option<u64>,
pub end_time: Option<u64>,
pub limit: Option<u32>,
pub cursor: Option<&'a str>,
}Expand description
Request for querying subaccount’s deposit records (on-chain)
Fields
id: Option<&'a str>Internal ID: Can be used to uniquely identify and filter the deposit. When combined with other parameters, this field takes the highest priority
tx_id: Option<&'a str>Transaction ID: Please note that data generated before Jan 1, 2024 cannot be queried using txID
sub_member_id: &'a strSub UID
coin: Option<&'a str>Coin, uppercase only
start_time: Option<u64>The start timestamp (ms) Note: the query logic is actually effective based on second level
end_time: Option<u64>The end timestamp (ms) Note: the query logic is actually effective based on second level
limit: Option<u32>Limit for data size per page. [1, 50]. Default: 50
cursor: Option<&'a str>Cursor. Use the nextPageCursor token from the response to retrieve the next page of the result set