pub struct SystemStatusItem {
pub id: String,
pub title: String,
pub state: String,
pub begin: u64,
pub end: u64,
pub href: String,
pub service_types: Vec<u32>,
pub product: Vec<u32>,
pub uid_suffix: Vec<u32>,
pub maintain_type: u32,
pub env: u32,
}Expand description
Represents a single system status/maintenance record
Fields
id: StringUnique identifier for the system status record
title: StringTitle of the system maintenance
state: StringSystem state (e.g., “completed”, “in_progress”, “scheduled”)
begin: u64Start time of system maintenance, timestamp in milliseconds
end: u64End time of system maintenance, timestamp in milliseconds. Before maintenance is completed, it is the expected end time; After maintenance is completed, it will be changed to the actual end time.
href: StringHyperlink to system maintenance details. Default value is empty string
service_types: Vec<u32>Service types affected by the maintenance
product: Vec<u32>Products affected by the maintenance
uid_suffix: Vec<u32>Affected UID tail numbers
maintain_type: u32Maintenance type
env: u32Environment