FutureTicker

Struct FutureTicker 

pub struct FutureTicker<'a> {
Show 24 fields pub symbol: &'a str, pub tick_direction: Option<&'a str>, pub price_24h_pcnt: Option<&'a str>, pub last_price: Option<&'a str>, pub prev_price_24h: Option<&'a str>, pub high_price_24h: Option<&'a str>, pub low_price_24h: Option<&'a str>, pub prev_price_1h: Option<&'a str>, pub mark_price: Option<&'a str>, pub index_price: Option<&'a str>, pub open_interest: Option<&'a str>, pub open_interest_value: Option<&'a str>, pub turnover_24h: Option<&'a str>, pub volume_24h: Option<&'a str>, pub next_funding_time: Option<&'a str>, pub funding_rate: Option<&'a str>, pub bid1_price: Option<&'a str>, pub bid1_size: Option<&'a str>, pub ask1_price: Option<&'a str>, pub ask1_size: Option<&'a str>, pub delivery_time: Option<&'a str>, pub basis_rate: Option<&'a str>, pub delivery_fee_rate: Option<&'a str>, pub predicted_delivery_price: Option<&'a str>,
}
The future ticker data.

This data utilises the snapshot field and delta field. None means field value has not changed.

Fields

symbol: &'a str

Symbol name.

tick_direction: Option<&'a str>

Tick direction.

price_24h_pcnt: Option<&'a str>

Percentage change of market price in the last 24 hours.

last_price: Option<&'a str>

Last price.

prev_price_24h: Option<&'a str>

Market price 24 hours ago.

high_price_24h: Option<&'a str>

The highest price in the last 24 hours.

low_price_24h: Option<&'a str>

The lowest price in the last 24 hours.

prev_price_1h: Option<&'a str>

Market price an hour ago.

mark_price: Option<&'a str>

Mark price.

index_price: Option<&'a str>

Index price.

open_interest: Option<&'a str>

Open interest size.

open_interest_value: Option<&'a str>

Open interest value.

turnover_24h: Option<&'a str>

Turnover for 24h.

volume_24h: Option<&'a str>

Volume for 24h.

next_funding_time: Option<&'a str>

Next funding timestamp (ms).

funding_rate: Option<&'a str>

Funding rate.

bid1_price: Option<&'a str>

Best bid price.

bid1_size: Option<&'a str>

Best bid size.

ask1_price: Option<&'a str>

Best ask price.

ask1_size: Option<&'a str>

Best ask size.

delivery_time: Option<&'a str>

Delivery date time (UTC+0). Unique field for inverse futures.

basis_rate: Option<&'a str>

Delivery fee rate. Unique field for inverse futures.

delivery_fee_rate: Option<&'a str>

Delivery fee rate. Unique field for inverse futures.

predicted_delivery_price: Option<&'a str>

Predicated delivery price. Unique field for inverse futures.