Wallet

Struct Wallet 

pub struct Wallet<'a> {
    pub account_type: &'a str,
    pub account_im_rate: &'a str,
    pub account_mm_rate: &'a str,
    pub total_equity: &'a str,
    pub total_wallet_balance: &'a str,
    pub total_margin_balance: &'a str,
    pub total_available_balance: &'a str,
    pub total_perp_upl: &'a str,
    pub total_initial_margin: &'a str,
    pub total_maintenance_margin: &'a str,
    pub coin: Vec<WalletCoin<'a>>,
}
The wallet data.

Fields

account_type: &'a str

Account type.

  • Unified account: UNIFIED.
  • Normal account: CONTRACT.
account_im_rate: &'a str

Initial Margin Rate: Account Total Initial Margin Base Coin / Account Margin Balance Base Coin. In non-unified mode, the field will be returned as an empty string.

account_mm_rate: &'a str

Maintenance Margin Rate: Account Total Maintenance Margin Base Coin / Account Margin Balance Base Coin. In non-unified mode, the field will be returned as an empty string.

total_equity: &'a str

Equity of account converted to usd:Account Margin Balance Base Coin + Account Option Value Base Coin. In non-unified mode, the field will be returned as an empty string.

total_wallet_balance: &'a str

Wallet Balance of account converted to usd:∑ Asset Wallet Balance By USD value of each asset. In non-unified mode, the field will be returned as an empty string.

total_margin_balance: &'a str

Margin Balance of account converted to usd:totalWalletBalance + totalPerpUPL. In non-unified mode, the field will be returned as an empty string.

total_available_balance: &'a str

Available Balance of account converted to usd:Regular mode:totalMarginBalance - totalInitialMargin. In non-unified mode, the field will be returned as an empty string.

total_perp_upl: &'a str

Unrealised P&L of perpetuals of account converted to usd:∑ Each perp upl by base coin. In non-unified mode, the field will be returned as an empty string.

total_initial_margin: &'a str

Initial Margin of account converted to usd:∑ Asset Total Initial Margin Base Coin. In non-unified mode, the field will be returned as an empty string.

total_maintenance_margin: &'a str

Maintenance Margin of account converted to usd: ∑ Asset Total Maintenance Margin Base Coin. In non-unified mode, the field will be returned as an empty string.

coin: Vec<WalletCoin<'a>>

Coin.