pub struct AllLiquidationSnapshotMsg {
pub time: Timestamp,
pub symbol: String,
pub side: Side,
pub size: Decimal,
pub price: Decimal,
}Fields
time: Timestampsymbol: Stringside: SideWhen you receive a Buy update, this means that a long position has been liquidated
size: Decimalprice: DecimalTrait Implementations
Sourceimpl Debug for AllLiquidationSnapshotMsg
impl Debug for AllLiquidationSnapshotMsg
Sourceimpl<'de> Deserialize<'de> for AllLiquidationSnapshotMsg
impl<'de> Deserialize<'de> for AllLiquidationSnapshotMsg
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl PartialEq for AllLiquidationSnapshotMsg
impl PartialEq for AllLiquidationSnapshotMsg
Sourcefn eq(&self, other: &AllLiquidationSnapshotMsg) -> bool
fn eq(&self, other: &AllLiquidationSnapshotMsg) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for AllLiquidationSnapshotMsg