ExecutionMsg

Struct ExecutionMsg 

pub struct ExecutionMsg {
Show 32 fields pub category: Category, pub symbol: String, pub is_leverage: bool, pub order_id: String, pub order_link_id: Option<String>, pub side: Side, pub order_price: Decimal, pub order_qty: Decimal, pub leaves_qty: Decimal, pub create_type: CreateType, pub order_type: OrderType, pub stop_order_type: StopOrderType, pub exec_fee: Decimal, pub exec_id: String, pub exec_price: Decimal, pub exec_qty: Decimal, pub exec_pnl: Decimal, pub exec_type: ExecType, pub exec_value: Decimal, pub exec_time: Timestamp, pub is_maker: bool, pub fee_rate: Decimal, pub trade_iv: Option<Decimal>, pub mark_iv: Option<Decimal>, pub mark_price: Decimal, pub index_price: Option<Decimal>, pub underlying_price: Option<Decimal>, pub block_trade_id: Option<String>, pub closed_size: Decimal, pub extra_fees: Option<Vec<ExtraFee>>, pub seq: i64, pub fee_currency: String,
}

Fields

category: Category

Product type spot, linear, inverse, option

symbol: String

Symbol name

is_leverage: bool

Whether to borrow. 0: false, 1: true

order_id: String

Order ID

order_link_id: Option<String>

User customized order ID

side: Side

Side. Buy,Sell

order_price: Decimal

Order price

order_qty: Decimal

Order qty

leaves_qty: Decimal

The remaining qty not executed

create_type: CreateType

Order create type Spot, Option do not have this key

order_type: OrderType

Order type. Market,Limit

stop_order_type: StopOrderType

Stop order type. If the order is not stop order, any type is not returned

exec_fee: Decimal

Executed trading fee. You can get spot fee currency instruction here

exec_id: String

Execution ID

exec_price: Decimal

Execution price

exec_qty: Decimal

Execution qty

exec_pnl: Decimal

Profit and Loss for each close position execution. The value keeps consistent with the field “cashFlow” in the Get Transaction Log

exec_type: ExecType

Executed type

exec_value: Decimal

Executed order value

exec_time: Timestamp

Executed timestamp (ms)

is_maker: bool

Is maker order. true: maker, false: taker

fee_rate: Decimal

Trading fee rate

trade_iv: Option<Decimal>

Implied volatility. valid for option

mark_iv: Option<Decimal>

Implied volatility of mark price. valid for option

mark_price: Decimal

The mark price of the symbol when executing. valid for option

index_price: Option<Decimal>

The index price of the symbol when executing. valid for option

underlying_price: Option<Decimal>

The underlying price of the symbol when executing. valid for option

block_trade_id: Option<String>

Paradigm block trade ID

closed_size: Decimal

Closed position size

extra_fees: Option<Vec<ExtraFee>>

Extra trading fee information. Currently, this data is returned only for kyc=Indian user or spot orders placed on the Indonesian site or spot fiat currency orders placed on the EU site. In other cases, an empty string is returned. Enum: feeType, subFeeType

seq: i64

Cross sequence, used to associate each fill and each position update The seq will be the same when conclude multiple transactions at the same time Different symbols may have the same seq, please use seq + symbol to check unique

fee_currency: String

Trading fee currency