pub struct FastExecutionMsg {Show 20 fields
pub category: Category,
pub symbol: String,
pub exec_id: String,
pub exec_price: Decimal,
pub exec_qty: Decimal,
pub side: Side,
pub order_qty: Decimal,
pub order_id: String,
pub order_link_id: Option<String>,
pub is_maker: bool,
pub fee_currency: String,
pub fee_rate: Decimal,
pub exec_fee: Decimal,
pub trade_iv: Option<Decimal>,
pub mark_iv: Option<Decimal>,
pub mark_price: Decimal,
pub index_price: Option<Decimal>,
pub underlying_price: Option<Decimal>,
pub block_trade_id: Option<String>,
pub exec_time: Timestamp,
}Expand description
A fill from the fastExecution private WS topic.
This is a condensed view of an execution that arrives immediately when an
order is matched, before the normal settlement cycle that drives
ExecutionMsg. The field set is smaller than ExecutionMsg.
Fields
category: Categorysymbol: Stringexec_id: Stringexec_price: Decimalexec_qty: Decimalside: Sideorder_qty: Decimalorder_id: Stringorder_link_id: Option<String>is_maker: boolfee_currency: Stringfee_rate: Decimalexec_fee: Decimaltrade_iv: Option<Decimal>mark_iv: Option<Decimal>mark_price: Decimalindex_price: Option<Decimal>underlying_price: Option<Decimal>block_trade_id: Option<String>exec_time: TimestampTrait Implementations
Sourceimpl Clone for FastExecutionMsg
impl Clone for FastExecutionMsg
Sourcefn clone(&self) -> FastExecutionMsg
fn clone(&self) -> FastExecutionMsg
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for FastExecutionMsg
impl Debug for FastExecutionMsg
Sourceimpl<'de> Deserialize<'de> for FastExecutionMsg
impl<'de> Deserialize<'de> for FastExecutionMsg
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl PartialEq for FastExecutionMsg
impl PartialEq for FastExecutionMsg
Sourcefn eq(&self, other: &FastExecutionMsg) -> bool
fn eq(&self, other: &FastExecutionMsg) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for FastExecutionMsg