pub struct GreekMsg {
pub base_coin: String,
pub total_delta: Decimal,
pub total_gamma: Decimal,
pub total_vega: Decimal,
pub total_theta: Decimal,
}Expand description
A data point from the greeks private WS topic.
Sent once per second when there is an option position. Contains the aggregate net greeks across all option positions for the base coin.
Fields
base_coin: Stringtotal_delta: Decimaltotal_gamma: Decimaltotal_vega: Decimaltotal_theta: DecimalTrait Implementations
Sourceimpl<'de> Deserialize<'de> for GreekMsg
impl<'de> Deserialize<'de> for GreekMsg
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl StructuralPartialEq for GreekMsg