pub trait Bybit<'a> {
// Required methods
fn new(
api_key: Option<Cow<'_, str>>,
secret_key: Option<Cow<'_, str>>,
) -> Self;
fn new_with_config(
config: &Config<'_>,
api_key: Option<Cow<'_, str>>,
secret_key: Option<Cow<'_, str>>,
) -> Self;
}Expand description
A trait that all modules must implement to be a Bybit API client module.
This trait provides two methods to create a new instance of the module, one with default configuration and one with custom configuration.
Required Methods
Object Safety
This trait is not object safe.