CurAuctionPhase

Enum CurAuctionPhase 

pub enum CurAuctionPhase {
    NotStarted,
    Finished,
    CallAuction,
    CallAuctionNoCancel,
    CrossMatching,
    ContinuousTrading,
}

Variants



NotStarted

Pre-market trading is not started



Finished

Pre-market trading is finished After the auction, if the pre-market contract fails to enter continues trading phase, it will be delisted and phase=“Finished” After the continuous trading, if the pre-market contract fails to be converted to official contract, it will be delisted and phase=“Finished”



CallAuction

Auction phase of pre-market trading only timeInForce=GTC, orderType=Limit order is allowed to submit TP/SL are not supported; Conditional orders are not supported cannot modify the order at this stage order price range: [preOpenPrice x 0.5, maxPrice]



CallAuctionNoCancel

Auction no cancel phase of pre-market trading only timeInForce=GTC, orderType=Limit order is allowed to submit TP/SL are not supported; Conditional orders are not supported cannot modify and cancel the order at this stage order price range: Buy [lastPrice x 0.5, markPrice x 1.1], Sell [markPrice x 0.9, maxPrice]



CrossMatching

cross matching phase cannot create, modify and cancel the order at this stage Candle data is released from this stage



ContinuousTrading

Continuous trading phase There is no restriction to create, amend, cancel orders orderbook, public trade data is released from this stage