pub struct General {
pub client: Client,
}Fields
client: ClientImplementations
sourceimpl General
impl General
The General struct represents general functionality for the Bybit API.
sourcepub async fn ping(&self) -> Result<String, BybitError>
pub async fn ping(&self) -> Result<String, BybitError>
Tests for connectivity by sending a ping request to the Bybit server.
Returns
Returns a Result containing a String with the response message if successful,
or a BybitError if an error occurs.
sourcepub async fn get_server_time(&self) -> Result<ServerTimeResponse, BybitError>
pub async fn get_server_time(&self) -> Result<ServerTimeResponse, BybitError>
Retrieves the server time from the Bybit API.
Returns
Returns a Result containing a ServerTime struct if successful,
or a BybitError if an error occurs.