pub struct APIKeyInformation {Show 22 fields
pub id: String,
pub note: String,
pub api_key: String,
pub read_only: i64,
pub secret: String,
pub permissions: APIKeyPermissions,
pub ips: Vec<String>,
pub key_type: i64,
pub deadline_day: u64,
pub expired_at: String,
pub created_at: String,
pub uta: i64,
pub user_id: i64,
pub inviter_id: i64,
pub vip_level: VipLevel,
pub mkt_maker_level: String,
pub affiliate_id: i64,
pub rsa_public_key: String,
pub is_master: bool,
pub parent_uid: String,
pub kyc_level: String,
pub kyc_region: String,
}Fields
id: StringUnique ID. Internal use
note: StringThe remark
api_key: StringApi key
read_only: i640:Read and Write. 1:Read only
secret: StringAlways “”
permissions: APIKeyPermissionsThe types of permission
ips: Vec<String>IP bound
key_type: i64The type of api key. 1:personal, 2:connected to the third-party app
deadline_day: u64The remaining valid days of api key. Only for those api key with no IP bound or the password has been changed
expired_at: StringThe expiry day of the api key. Only for those api key with no IP bound or the password has been changed
created_at: StringThe create day of the api key
uta: i64Whether the account to which the account upgrade to unified trade account. 0:regular account; 1:unified trade account
user_id: i64User ID
inviter_id: i64Inviter ID (the UID of the account which invited this account to the platform)
vip_level: VipLevelVIP Level
mkt_maker_level: StringMarket maker level
affiliate_id: i64Affiliate Id. 0 represents that there is no binding relationship.
rsa_public_key: StringRsa public key
is_master: boolIf this api key belongs to master account or not
parent_uid: StringThe main account uid. Returns “0” when the endpoint is called by main account
kyc_level: StringPersonal account kyc level. LEVEL_DEFAULT, LEVEL_1, LEVEL_2
kyc_region: StringPersonal account kyc region