pub struct LinearInverseTicker {Show 27 fields
pub symbol: String,
pub last_price: Decimal,
pub mark_price: Decimal,
pub index_price: Decimal,
pub prev_price24h: Decimal,
pub price24h_pcnt: Decimal,
pub high_price24h: Decimal,
pub low_price24h: Decimal,
pub prev_price1h: Decimal,
pub open_interest: Decimal,
pub open_interest_value: Decimal,
pub turnover24h: Decimal,
pub volume24h: Decimal,
pub funding_rate: Option<Decimal>,
pub next_funding_time: Timestamp,
pub predicted_delivery_price: Option<Decimal>,
pub basis_rate: Option<Decimal>,
pub basis: Option<Decimal>,
pub delivery_fee_rate: Option<Decimal>,
pub delivery_time: Option<Timestamp>,
pub bid1_price: Decimal,
pub bid1_size: Decimal,
pub ask1_price: Decimal,
pub ask1_size: Decimal,
pub pre_open_price: Option<Decimal>,
pub pre_qty: Option<Decimal>,
pub cur_pre_listing_phase: Option<CurAuctionPhase>,
}Fields
symbol: StringSymbol name
last_price: DecimalLast price
mark_price: DecimalMark price
index_price: DecimalIndex price
prev_price24h: DecimalMarket price 24 hours ago
price24h_pcnt: DecimalPercentage change of market price in the last 24 hours
high_price24h: DecimalThe highest price in the last 24 hours
low_price24h: DecimalThe lowest price in the last 24 hours
prev_price1h: DecimalMarket price an hour ago
open_interest: DecimalOpen interest size
open_interest_value: DecimalOpen interest value
turnover24h: DecimalTurnover for 24h
volume24h: DecimalVolume for 24h
funding_rate: Option<Decimal>Funding rate
next_funding_time: TimestampNext funding timestamp (ms)
predicted_delivery_price: Option<Decimal>Predicated delivery price. It has value when 30 min before delivery
basis_rate: Option<Decimal>Basis rate. Unique field for inverse futures & USDC futures
basis: Option<Decimal>Basis. Unique field for inverse futures & USDC futures
delivery_fee_rate: Option<Decimal>Delivery fee rate. Unique field for inverse futures & USDC futures
delivery_time: Option<Timestamp>Delivery date time (UTC+0). Unique field for inverse futures & USDC futures
bid1_price: DecimalBest bid price
bid1_size: DecimalBest bid size
ask1_price: DecimalBest ask price
ask1_size: DecimalBest ask size
pre_open_price: Option<Decimal>Estimated pre-market contract open price. The value is meaningless when entering continuous trading phase.
pre_qty: Option<Decimal>Estimated pre-market contract open qty. The value is meaningless when entering continuous trading phase.
cur_pre_listing_phase: Option<CurAuctionPhase>Enum: NotStarted, Finished, CallAuction, CallAuctionNoCancel, CrossMatching, ContinuousTrading.