SpotInstrumentsInfo

Struct SpotInstrumentsInfo 

pub struct SpotInstrumentsInfo {
    pub symbol: String,
    pub base_coin: String,
    pub quote_coin: String,
    pub innovation: bool,
    pub status: Status,
    pub margin_trading: String,
    pub st_tag: bool,
    pub lot_size_filter: SpotLotSizeFilter,
    pub price_filter: SpotPriceFilter,
    pub risk_parameters: RiskParameters,
}

Fields

symbol: String

Symbol name

base_coin: String

Base coin

quote_coin: String

Quote coin

innovation: bool

Whether or not this is an innovation zone token. 0: false, 1: true

status: Status

Instrument status

margin_trading: String

Margin trade symbol or not This is to identify if the symbol support margin trading under different account modes You may find some symbols not supporting margin buy or margin sell, so you need to go to Collateral Info (UTA) to check if that coin is borrowable

st_tag: bool

Whether or not it has an special treatment label. 0: false, 1: true

lot_size_filter: SpotLotSizeFilter

Size attributes

price_filter: SpotPriceFilter

Price attributes

risk_parameters: RiskParameters

Risk parameters for limit order price, refer to announcement