pub struct TransactionLog {Show 22 fields
pub id: String,
pub symbol: String,
pub category: Category,
pub side: Side,
pub transaction_time: Timestamp,
pub log_type: String,
pub trans_sub_type: String,
pub qty: Decimal,
pub size: Decimal,
pub currency: String,
pub trade_price: Decimal,
pub funding: Decimal,
pub fee: Decimal,
pub cash_flow: Decimal,
pub change: Decimal,
pub cash_balance: Decimal,
pub fee_rate: Decimal,
pub bonus_change: Decimal,
pub trade_id: String,
pub order_id: String,
pub order_link_id: Option<String>,
pub extra_fees: Option<Value>,
}Fields
id: StringUnique id
symbol: StringSymbol name
category: CategoryProduct type
side: SideSide. Buy,Sell,None
transaction_time: TimestampTransaction timestamp (ms)
log_type: StringType
trans_sub_type: StringTransaction sub type, movePosition, used for the logs generated by move position. “” by default
qty: DecimalQuantity Spot: the negative means the qty of this currency is decreased, the positive means the qty of this currency is increased Perps & Futures: it is the quantity for each trade entry and it does not have direction
size: DecimalSize. The rest position size after the trade is executed, and it has direction, i.e., short with “-”
currency: Stringe.g., USDC, USDT, BTC, ETH
trade_price: DecimalTrade price
funding: DecimalFunding fee Positive fee value means receive funding; negative fee value means pay funding. This is opposite to the execFee from Get Trade History. For USDC Perp, as funding settlement and session settlement occur at the same time, they are represented in a single record at settlement. Please refer to funding to understand funding fee, and cashFlow to understand 8-hour P&L.
fee: DecimalTrading fee Positive fee value means expense Negative fee value means rebates
cash_flow: DecimalCash flow, e.g., (1) close the position, and unRPL converts to RPL, (2) 8-hour session settlement for USDC Perp and Futures, (3) transfer in or transfer out. This does not include trading fee, funding fee
change: DecimalChange = cashFlow + funding - fee
cash_balance: DecimalCash balance. This is the wallet balance after a cash change
fee_rate: DecimalWhen type=TRADE, then it is trading fee rate When type=SETTLEMENT, it means funding fee rate. For side=Buy, feeRate=market fee rate; For side=Sell, feeRate= - market fee rate
bonus_change: DecimalThe change of bonus
trade_id: StringTrade ID
order_id: StringOrder ID
order_link_id: Option<String>User customised order ID
extra_fees: Option<Value>Trading fee rate information. Currently, this data is returned only for spot orders placed on the Indonesian site or spot fiat currency orders placed on the EU site. In other cases, an empty string is returned. Enum: feeType, subFeeType