Struct bybit::position::PositionManager

source ·
pub struct PositionManager {
    pub client: Client,
    pub recv_window: u64,
}

Fields

client: Clientrecv_window: u64

Implementations

source

impl PositionManager

source

pub async fn get_info<'a>( &self, req: PositionRequest<'a>, ) -> Result<InfoResponse, BybitError>

Asynchronously retrieves information about a position based on the provided request.

Arguments
  • req - The position request containing the category, symbol, base coin, settle coin, and limit.
Returns

A Result containing a vector of PositionInfo if the operation is successful, or an error if it fails.

Example
use crate::model::{PositionRequest, Category};
use crate::errors::Result;
use crate::api::PositionInfo;
use my_module::PositionManager;

#[tokio::main]
async fn main() -> Result<()> {
    let position_manager = PositionManager::new();
    let request = PositionRequest::new(Category::Linear, Some("symbol"), Some("base_coin"), Some("settle_coin"), Some(10));
    let position_info = position_manager.get_info(request).await?;
    Ok(())
}
source

pub async fn set_leverage<'a>( &self, req: LeverageRequest<'a>, ) -> Result<LeverageResponse, BybitError>

Arguments
  • req - The leverage request containing category, symbol, and leverage.
Returns

A result containing the leverage response.

source

pub async fn set_margin_mode<'a>( &self, req: ChangeMarginRequest<'a>, ) -> Result<ChangeMarginResponse, BybitError>

Set the margin mode.

Arguments
  • req - The ChangeMarginRequest containing the necessary information.
Returns
  • Result - The result of setting the margin mode.
source

pub async fn set_position_mode<'a>( &self, req: MarginModeRequest<'a>, ) -> Result<MarginModeResponse, BybitError>

Set the position mode.

Arguments
  • req - The MarginModeRequest containing the necessary information.
Returns
  • Result - The result of setting the position mode.
source

pub async fn set_risk_limit<'a>( &self, req: SetRiskLimit<'a>, ) -> Result<SetRiskLimitResponse, BybitError>

Set the risk limit.

Arguments
  • req - The SetRiskLimitRequest containing the necessary information.
Returns
  • Result - The result of setting the risk limit.
source

pub async fn set_trading_stop<'a>( &self, req: TradingStopRequest<'a>, ) -> Result<TradingStopResponse, BybitError>

Set the trading stop.

Arguments
  • req - The TradingStopRequest containing the necessary information.
Returns
  • Result - The result of setting the trading stop.
source

pub async fn set_add_margin<'a>( &self, req: AddMarginRequest<'a>, ) -> Result<AddMarginResponse, BybitError>

source

pub async fn add_or_reduce_margin<'a>( &self, req: AddReduceMarginRequest<'a>, ) -> Result<AddReduceMarginResponse, BybitError>

source

pub async fn get_closed_pnl<'a>( &self, req: ClosedPnlRequest<'a>, ) -> Result<ClosedPnlResponse, BybitError>

source

pub async fn move_position<'a>( &self, req: MovePositionRequest<'a>, ) -> Result<MovePositionResponse, BybitError>

source

pub async fn move_position_history<'a>( &self, req: MoveHistoryRequest<'a>, ) -> Result<MoveHistoryResponse, BybitError>