SpotMarginCode

Enum SpotMarginCode 

#[repr(i32)]
pub enum SpotMarginCode { MarginTradingNotEnabled = 132_001, MarginTradingDisabledSubAccount = 132_002, MarginTradingDisabledMasterAccount = 132_003, InsufficientMarginBalance = 132_004, InvalidLeverage = 132_005, InvalidBorrowAmount = 132_006, BorrowFailed = 132_007, RepayFailed = 132_008, InvalidRepayAmount = 132_009, MarginLevelTooLow = 132_010, MarginTradingNotSupported = 132_011, InvalidMarginAccountType = 132_012, }
Enum representing Bybit API V5 Spot Margin error codes.

See: https://bybit-exchange.github.io/docs/v5/error#spot-margin-trade

Variants



MarginTradingNotEnabled = 132_001

Spot margin trading is not enabled.



MarginTradingDisabledSubAccount = 132_002

Spot margin trading is disabled for this sub-account.



MarginTradingDisabledMasterAccount = 132_003

Spot margin trading is disabled for this master account.



InsufficientMarginBalance = 132_004

Insufficient margin balance.



InvalidLeverage = 132_005

Invalid leverage.



InvalidBorrowAmount = 132_006

Invalid borrow amount.



BorrowFailed = 132_007

Borrow failed.



RepayFailed = 132_008

Repay failed.



InvalidRepayAmount = 132_009

Invalid repay amount.



MarginLevelTooLow = 132_010

Margin level is too low.



MarginTradingNotSupported = 132_011

Spot margin trading is not supported for this symbol.



InvalidMarginAccountType = 132_012

Invalid margin account type.

Implementations

Source

impl SpotMarginCode

pub fn from_code<T>(code: T) -> Option<Self>
where T: Into<i32> + Copy,

Converts an error code (as i32 or &str) to a SpotMarginError variant. Returns None if the code doesn’t match any variant.

pub fn message(&self) -> &'static str

Returns the error message associated with the error code.