pub struct AssetManager {
pub client: Client,
pub recv_window: u16,
}Fields
client: Clientrecv_window: u16Trait Implementations
Sourceimpl Bybit for AssetManager
impl Bybit for AssetManager
Sourcefn new(api_key: Option<String>, secret_key: Option<String>) -> AssetManager
fn new(api_key: Option<String>, secret_key: Option<String>) -> AssetManager
Creates a new instance of the module with default configuration. Read more
Sourcefn new_with_config(
config: &Config,
api_key: Option<String>,
secret_key: Option<String>,
) -> AssetManager
fn new_with_config( config: &Config, api_key: Option<String>, secret_key: Option<String>, ) -> AssetManager
Creates a new instance of the module with custom configuration. Read more
Sourceimpl Clone for AssetManager
impl Clone for AssetManager
Sourcefn clone(&self) -> AssetManager
fn clone(&self) -> AssetManager
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreAuto Trait Implementations
impl Freeze for AssetManager
impl !RefUnwindSafe for AssetManager
impl Send for AssetManager
impl Sync for AssetManager
impl Unpin for AssetManager
impl !UnwindSafe for AssetManager