Struct BybitContentError

pub struct BybitContentError {
    pub code: i32,
    pub msg: String,
}
BybitContentError is a struct that represents the error returned by the Bybit API. It has two fields: code, which is an i16 representing the error code, and msg, which is a String representing the error message.

Fields

code: i32

The raw error code returned by the Bybit API, you can use this to map to a specific error type by calling self.typed(), this is useful if you want to match on a specific error type.

msg: String

The error message returned by the Bybit API.

Implementations

Source

impl BybitContentError

pub fn typed(&self) -> Option<ReturnCode>

A typed version of the error code, this is useful if you want to match on a specific error type.