Struct PositionManager

pub struct PositionManager {
    pub client: Client,
    pub recv_window: u16,
}

Fields

client: Clientrecv_window: u16

Implementations

Source

impl PositionManager

pub async fn get_info<'b>( &self, req: PositionRequest<'_>, ) -> Result<InfoResponse, BybitError>

Asynchronously retrieves information about a position based on the provided request.

Arguments
  • req - The position request containing the category, symbol, base coin, settle coin, and limit.
Returns

A Result containing a vector of PositionInfo if the operation is successful, or an error if it fails.

Example
use crate::model::{PositionRequest, Category};
use crate::errors::Result;
use crate::api::PositionInfo;
use my_module::PositionManager;

#[tokio::main]
async fn main() -> Result<()> {
    let position_manager = PositionManager::new();
    let request = PositionRequest::new(Category::Linear, Some("symbol"), Some("base_coin"), Some("settle_coin"), Some(10));
    let position_info = position_manager.get_info(request).await?;
    Ok(())
}
pub async fn set_leverage<'b>( &self, req: LeverageRequest<'_>, ) -> Result<LeverageResponse, BybitError>

Arguments
  • req - The leverage request containing category, symbol, and leverage.
Returns

A result containing the leverage response.

pub async fn set_margin_mode<'b>( &self, req: ChangeMarginRequest<'_>, ) -> Result<ChangeMarginResponse, BybitError>

Set the margin mode.

Arguments
  • req - The ChangeMarginRequest containing the necessary information.
Returns
  • Result - The result of setting the margin mode.
pub async fn set_position_mode<'b>( &self, req: MarginModeRequest<'_>, ) -> Result<MarginModeResponse, BybitError>

Set the position mode.

Arguments
  • req - The MarginModeRequest containing the necessary information.
Returns
  • Result - The result of setting the position mode.
pub async fn set_risk_limit<'b>( &self, req: SetRiskLimit<'_>, ) -> Result<SetRiskLimitResponse, BybitError>

Set the risk limit.

Arguments
  • req - The SetRiskLimitRequest containing the necessary information.
Returns
  • Result - The result of setting the risk limit.
pub async fn set_trading_stop<'b>( &self, req: TradingStopRequest<'_>, ) -> Result<TradingStopResponse, BybitError>

Set the trading stop.

Arguments
  • req - The TradingStopRequest containing the necessary information.
Returns
  • Result - The result of setting the trading stop.
pub async fn set_add_margin<'b>( &self, req: AddMarginRequest<'_>, ) -> Result<AddMarginResponse, BybitError>

Set the auto-add margin mode for a given position.

Arguments
  • req - The AddMarginRequest containing the necessary information.
Returns

A result containing the AddMarginResponse.

pub async fn add_or_reduce_margin<'b>( &self, req: AddReduceMarginRequest<'_>, ) -> Result<AddReduceMarginResponse, BybitError>

Set the auto add margin.

Arguments
  • req - The AddReduceMarginRequest containing the necessary information.
Returns
  • Result - The result of setting the auto add margin.
pub async fn get_closed_pnl<'b>( &self, req: ClosedPnlRequest<'_>, ) -> Result<ClosedPnlResponse, BybitError>

pub async fn move_position<'b>( &self, req: MovePositionRequest<'_>, ) -> Result<MovePositionResponse, BybitError>

Moves positions from one user to another.

Arguments
  • req - The request containing the fromUid, toUid, and list of positions to move.
Returns

A result containing the response.

pub async fn move_position_history<'b>( &self, req: MoveHistoryRequest<'_>, ) -> Result<MoveHistoryResponse, BybitError>

Retrieves the history of position movements.

Arguments
  • req - The request containing the parameters for the history of position movements.
Returns

A result containing the response.