pub struct PositionManager {
pub client: Client,
pub recv_window: u16,
}Fields
client: Clientrecv_window: u16Implementations
Sourceimpl PositionManager
impl PositionManager
Sourcepub async fn get_info<'b>(
&self,
req: PositionRequest<'_>,
) -> Result<InfoResponse, BybitError>
pub async fn get_info<'b>( &self, req: PositionRequest<'_>, ) -> Result<InfoResponse, BybitError>
Asynchronously retrieves information about a position based on the provided request.
Arguments
req- The position request containing the category, symbol, base coin, settle coin, and limit.
Returns
A Result containing a vector of PositionInfo if the operation is successful, or an error if it fails.
Example
use crate::model::{PositionRequest, Category};
use crate::errors::Result;
use crate::api::PositionInfo;
use my_module::PositionManager;
#[tokio::main]
async fn main() -> Result<()> {
let position_manager = PositionManager::new();
let request = PositionRequest::new(Category::Linear, Some("symbol"), Some("base_coin"), Some("settle_coin"), Some(10));
let position_info = position_manager.get_info(request).await?;
Ok(())
}Sourcepub async fn set_leverage<'b>(
&self,
req: LeverageRequest<'_>,
) -> Result<LeverageResponse, BybitError>
pub async fn set_leverage<'b>( &self, req: LeverageRequest<'_>, ) -> Result<LeverageResponse, BybitError>
Sourcepub async fn set_margin_mode<'b>(
&self,
req: ChangeMarginRequest<'_>,
) -> Result<ChangeMarginResponse, BybitError>
pub async fn set_margin_mode<'b>( &self, req: ChangeMarginRequest<'_>, ) -> Result<ChangeMarginResponse, BybitError>
Sourcepub async fn set_position_mode<'b>(
&self,
req: MarginModeRequest<'_>,
) -> Result<MarginModeResponse, BybitError>
pub async fn set_position_mode<'b>( &self, req: MarginModeRequest<'_>, ) -> Result<MarginModeResponse, BybitError>
Sourcepub async fn set_risk_limit<'b>(
&self,
req: SetRiskLimit<'_>,
) -> Result<SetRiskLimitResponse, BybitError>
pub async fn set_risk_limit<'b>( &self, req: SetRiskLimit<'_>, ) -> Result<SetRiskLimitResponse, BybitError>
Sourcepub async fn set_trading_stop<'b>(
&self,
req: TradingStopRequest<'_>,
) -> Result<TradingStopResponse, BybitError>
pub async fn set_trading_stop<'b>( &self, req: TradingStopRequest<'_>, ) -> Result<TradingStopResponse, BybitError>
Sourcepub async fn set_add_margin<'b>(
&self,
req: AddMarginRequest<'_>,
) -> Result<AddMarginResponse, BybitError>
pub async fn set_add_margin<'b>( &self, req: AddMarginRequest<'_>, ) -> Result<AddMarginResponse, BybitError>
Sourcepub async fn add_or_reduce_margin<'b>(
&self,
req: AddReduceMarginRequest<'_>,
) -> Result<AddReduceMarginResponse, BybitError>
pub async fn add_or_reduce_margin<'b>( &self, req: AddReduceMarginRequest<'_>, ) -> Result<AddReduceMarginResponse, BybitError>
pub async fn get_closed_pnl<'b>( &self, req: ClosedPnlRequest<'_>, ) -> Result<ClosedPnlResponse, BybitError>
Sourcepub async fn move_position<'b>(
&self,
req: MovePositionRequest<'_>,
) -> Result<MovePositionResponse, BybitError>
pub async fn move_position<'b>( &self, req: MovePositionRequest<'_>, ) -> Result<MovePositionResponse, BybitError>
Sourcepub async fn move_position_history<'b>(
&self,
req: MoveHistoryRequest<'_>,
) -> Result<MoveHistoryResponse, BybitError>
pub async fn move_position_history<'b>( &self, req: MoveHistoryRequest<'_>, ) -> Result<MoveHistoryResponse, BybitError>