pub struct WithdrawRequest<'a> {
pub coin: &'a str,
pub chain: Option<&'a str>,
pub address: &'a str,
pub tag: Option<&'a str>,
pub amount: &'a str,
pub timestamp: u64,
pub force_chain: Option<i32>,
pub account_type: &'a str,
pub fee_type: Option<i32>,
pub request_id: Option<&'a str>,
pub beneficiary: Option<BeneficiaryInfo<'a>>,
}Expand description
Request for creating a withdrawal
Fields
coin: &'a strCoin, uppercase only
chain: Option<&'a str>Chain
forceChain=0 or 1: this field is requiredforceChain=2: this field can be null
address: &'a strAddress
forceChain=0 or 1: fill wallet address, and make sure you add address in the address book first. Please note that the address is case sensitive, so use the exact same address added in address bookforceChain=2: fill Bybit UID, and it can only be another Bybit main account UID. Make sure you add UID in the address book first
tag: Option<&'a str>Tag
- Required if tag exists in the wallet address list.
- Note: please do not set a tag/memo in the address book if the chain does not support tag
amount: &'a strWithdraw amount
timestamp: u64Current timestamp (ms). Used for preventing from withdraw replay
force_chain: Option<i32>Whether or not to force an on-chain withdrawal
0(default): If the address is parsed out to be an internal address, then internal transfer (Bybit main account only)1: Force the withdrawal to occur on-chain2: Use UID to withdraw
account_type: &'a strSelect the wallet to be withdrawn from
FUND: Funding walletUTA: System transfers the funds to Funding wallet to withdrawFUND,UTA: For combo withdrawals, funds will be deducted from the Funding wallet first. If the balance is insufficient, the remaining amount will be deducted from the UTA wallet.
fee_type: Option<i32>Handling fee option
0(default): input amount is the actual amount received, so you have to calculate handling fee manually1: input amount is not the actual amount you received, the system will help to deduct the handling fee automatically
request_id: Option<&'a str>Customised ID, globally unique, it is used for idempotent verification
- A combination of letters (case sensitive) and numbers, which can be pure letters or pure numbers and the length must be between 1 and 32 digits
beneficiary: Option<BeneficiaryInfo<'a>>Travel rule info. It is required for kyc/kyb=KOR (Korean), kyc=IND (India) users, and users who registered in Bybit Turkey(TR), Bybit Kazakhstan(KZ), Bybit Indonesia (ID)