pub struct ExecutionMsg {Show 32 fields
pub category: Category,
pub symbol: String,
pub is_leverage: bool,
pub order_id: String,
pub order_link_id: Option<String>,
pub side: Side,
pub order_price: Decimal,
pub order_qty: Decimal,
pub leaves_qty: Decimal,
pub create_type: CreateType,
pub order_type: OrderType,
pub stop_order_type: StopOrderType,
pub exec_fee: Decimal,
pub exec_id: String,
pub exec_price: Decimal,
pub exec_qty: Decimal,
pub exec_pnl: Decimal,
pub exec_type: ExecType,
pub exec_value: Decimal,
pub exec_time: Timestamp,
pub is_maker: bool,
pub fee_rate: Decimal,
pub trade_iv: Option<Decimal>,
pub mark_iv: Option<Decimal>,
pub mark_price: Decimal,
pub index_price: Option<Decimal>,
pub underlying_price: Option<Decimal>,
pub block_trade_id: Option<String>,
pub closed_size: Decimal,
pub extra_fees: Option<Vec<ExtraFee>>,
pub seq: i64,
pub fee_currency: String,
}Fields
category: CategoryProduct type spot, linear, inverse, option
symbol: StringSymbol name
is_leverage: boolWhether to borrow. 0: false, 1: true
order_id: StringOrder ID
order_link_id: Option<String>User customized order ID
side: SideSide. Buy,Sell
order_price: DecimalOrder price
order_qty: DecimalOrder qty
leaves_qty: DecimalThe remaining qty not executed
create_type: CreateTypeOrder create type Spot, Option do not have this key
order_type: OrderTypeOrder type. Market,Limit
stop_order_type: StopOrderTypeStop order type. If the order is not stop order, any type is not returned
exec_fee: DecimalExecuted trading fee. You can get spot fee currency instruction here
exec_id: StringExecution ID
exec_price: DecimalExecution price
exec_qty: DecimalExecution qty
exec_pnl: DecimalProfit and Loss for each close position execution. The value keeps consistent with the field “cashFlow” in the Get Transaction Log
exec_type: ExecTypeExecuted type
exec_value: DecimalExecuted order value
exec_time: TimestampExecuted timestamp (ms)
is_maker: boolIs maker order. true: maker, false: taker
fee_rate: DecimalTrading fee rate
trade_iv: Option<Decimal>Implied volatility. valid for option
mark_iv: Option<Decimal>Implied volatility of mark price. valid for option
mark_price: DecimalThe mark price of the symbol when executing. valid for option
index_price: Option<Decimal>The index price of the symbol when executing. valid for option
underlying_price: Option<Decimal>The underlying price of the symbol when executing. valid for option
block_trade_id: Option<String>Paradigm block trade ID
closed_size: DecimalClosed position size
extra_fees: Option<Vec<ExtraFee>>Extra trading fee information. Currently, this data is returned only for kyc=Indian user or spot orders placed on the Indonesian site or spot fiat currency orders placed on the EU site. In other cases, an empty string is returned. Enum: feeType, subFeeType
seq: i64Cross sequence, used to associate each fill and each position update The seq will be the same when conclude multiple transactions at the same time Different symbols may have the same seq, please use seq + symbol to check unique
fee_currency: StringTrading fee currency