pub struct OrderbookDataMsg {
pub symbol: String,
pub bids: Vec<OrderbookLevel>,
pub asks: Vec<OrderbookLevel>,
pub update_id: i64,
pub seq: i64,
}Fields
symbol: StringSymbol name
bids: Vec<OrderbookLevel>Bid, buy side. For snapshot, sorted by price in descending order. For delta, size 0 means delete the price level
asks: Vec<OrderbookLevel>Ask, sell side. For snapshot, sorted by price in ascending order. For delta, size 0 means delete the price level
update_id: i64Update ID, is a sequence. Occasionally, you’ll receive “u”=1, which is a snapshot data due to the restart of the websocket service. So please overwrite your local orderbook
seq: i64Cross sequence. You can use this field to compare different levels orderbook data, and for the smaller seq, then it means the data is generated earlier