Struct bybit::ws::Stream

source ·
pub struct Stream {
    pub client: Client,
}

Fields

client: Client

Implementations

source

impl Stream

source

pub fn ws_ping(&self, private: bool) -> Result<()>

source

pub fn ws_priv_subscribe<'a, F>( &self, req: Subscription<'a>, handler: F ) -> Result<()>
where F: FnMut(WebsocketEvents) -> Result<()> + 'static + Send,

source

pub fn ws_subscribe<'a, F>( &self, req: Subscription<'a>, category: Category, handler: F ) -> Result<()>
where F: FnMut(WebsocketEvents) -> Result<()> + 'static + Send,

source

pub fn build_subscription(action: Subscription<'_>) -> String

source

pub fn ws_orderbook( &self, subs: Vec<(i32, &str)>, category: Category ) -> Result<()>

Subscribes to the specified order book updates and handles the order book events

Arguments
  • subs - A vector of tuples containing the order book ID and symbol
  • category - The category of the order book
Example
use your_crate_name::Category;
let subs = vec![(1, "BTC"), (2, "ETH")];
source

pub fn ws_trades(&self, subs: Vec<&str>, category: Category) -> Result<()>

This function subscribes to the specified trades and handles the trade events.

Arguments
  • subs - A vector of trade subscriptions
  • category - The category of the trades
Example
use your_crate_name::Category;
let subs = vec!["BTCUSD", "ETHUSD"];
let category = Category::Linear;
ws_trades(subs, category);
source

pub fn ws_tickers(&self, subs: Vec<&str>, category: Category) -> Result<()>

Subscribes to ticker events for the specified symbols and category.

Arguments
  • subs - A vector of symbols for which ticker events are subscribed.
  • category - The category for which ticker events are subscribed.
Examples
use your_crate_name::Category;
let subs = vec!["BTCUSD", "ETHUSD"];
let category = Category::Linear;
ws_tickers(subs, category);
source

pub fn ws_klines( &self, subs: Vec<(&str, &str)>, category: Category ) -> Result<()>

source

pub fn ws_position(&self, cat: Option<Category>) -> Result<()>

source

pub fn ws_executions(&self, cat: Option<Category>) -> Result<()>

source

pub fn ws_orders(&self, cat: Option<Category>) -> Result<()>

source

pub fn ws_wallet(&self) -> Result<()>

source

pub fn event_loop<H>( stream: WebSocket<MaybeTlsStream<TcpStream>>, handler: H ) -> Result<()>