pub struct WalletMsg {Show 15 fields
pub account_type: AccountType,
pub account_im_rate: Decimal,
pub account_mm_rate: Decimal,
pub total_equity: Decimal,
pub total_wallet_balance: Decimal,
pub total_margin_balance: Decimal,
pub total_available_balance: Decimal,
pub total_perp_upl: Decimal,
pub total_initial_margin: Decimal,
pub total_maintenance_margin: Decimal,
pub account_im_rate_by_mp: Decimal,
pub account_mm_rate_by_mp: Decimal,
pub total_initial_margin_by_mp: Decimal,
pub total_maintenance_margin_by_mp: Decimal,
pub coin: HashMap<String, WalletCoin>,
}Fields
account_type: AccountTypeAccount type. UTA2.0: UNIFIED UTA1.0: UNIFIED (spot/linear/options), CONTRACT(inverse) Classic: CONTRACT, SPOT
account_im_rate: DecimalAccount IM rate You can refer to this Glossary to understand the below fields calculation and mearning All below account wide fields are not applicable to UTA2.0(isolated margin), UTA1.0(isolated margin), UTA1.0(CONTRACT), classic account(SPOT, CONTRACT)
account_mm_rate: DecimalAccount MM rate
total_equity: DecimalAccount total equity (USD)
total_wallet_balance: DecimalAccount wallet balance (USD): ∑Asset Wallet Balance By USD value of each asset
total_margin_balance: DecimalAccount margin balance (USD): totalWalletBalance + totalPerpUPL
total_available_balance: DecimalAccount available balance (USD), Cross Margin: totalMarginBalance - totalInitialMargin
total_perp_upl: DecimalAccount Perps and Futures unrealised p&l (USD): ∑Each Perp and USDC Futures upl by base coin
total_initial_margin: DecimalAccount initial margin (USD): ∑Asset Total Initial Margin Base Coin
total_maintenance_margin: DecimalAccount maintenance margin (USD): ∑ Asset Total Maintenance Margin Base Coin
account_im_rate_by_mp: DecimalYou can ignore this field, and refer to accountIMRate, which has the same calculation
account_mm_rate_by_mp: DecimalYou can ignore this field, and refer to accountMMRate, which has the same calculation
total_initial_margin_by_mp: DecimalYou can ignore this field, and refer to totalInitialMargin, which has the same calculation
total_maintenance_margin_by_mp: DecimalYou can ignore this field, and refer to totalMaintenanceMargin, which has the same calculation
coin: HashMap<String, WalletCoin>